@@ -1,7 +1,7 @@
 #!/usr/bin/env python3
 #------------------------------------------------------------------------------#
 #  fortnet-python: Python Tools for the Fortnet Software Package               #
-#  Copyright (C) 2021 T. W. van der Heide                                      #
+#  Copyright (C) 2021 - 2022 T. W. van der Heide                               #
 #                                                                              #
 #  See the LICENSE file for terms of usage and distribution.                   #
 #------------------------------------------------------------------------------#
@@ -30,8 +30,8 @@ def test_csgeometries(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: No
-        atomic targets: /
+        global targets: No
+        atomic targets: No
         external features: No
         manual dataset weights: No
         manual gradient weights: No
@@ -55,8 +55,8 @@ def test_cgeometries(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: No
-        atomic targets: /
+        global targets: No
+        atomic targets: No
         external features: No
         manual dataset weights: No
         manual gradient weights: No
@@ -80,8 +80,8 @@ def test_extfeatures(tmpdir):
 
         structures: No
         periodic: /
-        targets: No
-        atomic targets: /
+        global targets: No
+        atomic targets: No
         external features: Yes
         manual dataset weights: No
         manual gradient weights: No
@@ -111,8 +111,8 @@ def test_cgeometries_extfeatures(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: No
-        atomic targets: /
+        global targets: No
+        atomic targets: No
         external features: Yes
         manual dataset weights: No
         manual gradient weights: No
@@ -137,8 +137,8 @@ def test_cgeometries_weights(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: No
-        atomic targets: /
+        global targets: No
+        atomic targets: No
         external features: No
         manual dataset weights: Yes
         manual gradient weights: No
@@ -166,7 +166,7 @@ def test_cgeometries_atomictargets(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: No
         manual dataset weights: No
@@ -178,7 +178,7 @@ def test_cgeometries_atomictargets(tmpdir):
     catoms = get_cluster_geometries()
     targets = get_properties_byatoms(catoms, 3, True)
 
-    fnetdata = Fnetdata(atoms=catoms, targets=targets, atomic=True)
+    fnetdata = Fnetdata(atoms=catoms, atomictargets=targets)
     fnetdata.dump(os.path.join(tmpdir, fname))
 
     hdf5 = Hdf5(os.path.join(tmpdir, fname))
@@ -192,7 +192,7 @@ def test_cgeometries_atomictargets_extfeatures(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: Yes
         manual dataset weights: No
@@ -205,8 +205,7 @@ def test_cgeometries_atomictargets_extfeatures(tmpdir):
     targets = get_properties_byatoms(catoms, 3, True)
     features = get_properties_byatoms(catoms, 13, True)
 
-    fnetdata = Fnetdata(atoms=catoms, features=features, targets=targets,
-                        atomic=True)
+    fnetdata = Fnetdata(atoms=catoms, features=features, atomictargets=targets)
     fnetdata.dump(os.path.join(tmpdir, fname))
 
     hdf5 = Hdf5(os.path.join(tmpdir, fname))
@@ -220,7 +219,7 @@ def test_cgeometries_atomictargets_weights(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: No
         manual dataset weights: Yes
@@ -235,7 +234,7 @@ def test_cgeometries_atomictargets_weights(tmpdir):
     weights = np.random.randint(1, 100, len(catoms), dtype=int)
     targets = get_properties_byatoms(catoms, 3, True)
 
-    fnetdata = Fnetdata(atoms=catoms, targets=targets, atomic=True)
+    fnetdata = Fnetdata(atoms=catoms, atomictargets=targets)
     fnetdata.weights = weights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -250,7 +249,7 @@ def test_cgeometries_atomictargets_atomicweights(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: No
         manual dataset weights: No
@@ -263,7 +262,7 @@ def test_cgeometries_atomictargets_atomicweights(tmpdir):
     atomicweights = get_atomicweights_byatoms(catoms)
     targets = get_properties_byatoms(catoms, 3, True)
 
-    fnetdata = Fnetdata(atoms=catoms, targets=targets, atomic=True)
+    fnetdata = Fnetdata(atoms=catoms, atomictargets=targets)
     fnetdata.atomicweights = atomicweights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -278,7 +277,7 @@ def test_cgeometries_atomictargets_batomicweights(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: No
         manual dataset weights: No
@@ -291,7 +290,7 @@ def test_cgeometries_atomictargets_batomicweights(tmpdir):
     batomicweights = get_batomicweights_byatoms(catoms)
     targets = get_properties_byatoms(catoms, 3, True)
 
-    fnetdata = Fnetdata(atoms=catoms, targets=targets, atomic=True)
+    fnetdata = Fnetdata(atoms=catoms, atomictargets=targets)
     fnetdata.atomicweights = batomicweights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -306,7 +305,7 @@ def test_cgeometries_globaltargets(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: No
         manual dataset weights: No
@@ -318,7 +317,7 @@ def test_cgeometries_globaltargets(tmpdir):
     catoms = get_cluster_geometries()
     targets = get_properties_byatoms(catoms, 3, False)
 
-    fnetdata = Fnetdata(atoms=catoms, targets=targets, atomic=False)
+    fnetdata = Fnetdata(atoms=catoms, globaltargets=targets)
     fnetdata.dump(os.path.join(tmpdir, fname))
 
     hdf5 = Hdf5(os.path.join(tmpdir, fname))
@@ -332,7 +331,7 @@ def test_cgeometries_globaltargets_extfeatures(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: Yes
         manual dataset weights: No
@@ -345,8 +344,7 @@ def test_cgeometries_globaltargets_extfeatures(tmpdir):
     targets = get_properties_byatoms(catoms, 3, False)
     features = get_properties_byatoms(catoms, 13, True)
 
-    fnetdata = Fnetdata(atoms=catoms, features=features, targets=targets,
-                        atomic=False)
+    fnetdata = Fnetdata(atoms=catoms, features=features, globaltargets=targets)
     fnetdata.dump(os.path.join(tmpdir, fname))
 
     hdf5 = Hdf5(os.path.join(tmpdir, fname))
@@ -360,7 +358,7 @@ def test_cgeometries_globaltargets_weights(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: No
         manual dataset weights: Yes
@@ -375,7 +373,7 @@ def test_cgeometries_globaltargets_weights(tmpdir):
     weights = np.random.randint(1, 100, len(catoms), dtype=int)
     targets = get_properties_byatoms(catoms, 3, False)
 
-    fnetdata = Fnetdata(atoms=catoms, targets=targets, atomic=False)
+    fnetdata = Fnetdata(atoms=catoms, globaltargets=targets)
     fnetdata.weights = weights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -390,7 +388,7 @@ def test_cgeometries_globaltargets_atomicweights(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: No
         manual dataset weights: No
@@ -403,7 +401,7 @@ def test_cgeometries_globaltargets_atomicweights(tmpdir):
     atomicweights = get_atomicweights_byatoms(catoms)
     targets = get_properties_byatoms(catoms, 3, False)
 
-    fnetdata = Fnetdata(atoms=catoms, targets=targets, atomic=False)
+    fnetdata = Fnetdata(atoms=catoms, globaltargets=targets)
     fnetdata.atomicweights = atomicweights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -418,7 +416,7 @@ def test_cgeometries_globaltargets_batomicweights(tmpdir):
 
         structures: Yes
         periodic: No
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: No
         manual dataset weights: No
@@ -431,7 +429,7 @@ def test_cgeometries_globaltargets_batomicweights(tmpdir):
     batomicweights = get_batomicweights_byatoms(catoms)
     targets = get_properties_byatoms(catoms, 3, False)
 
-    fnetdata = Fnetdata(atoms=catoms, targets=targets, atomic=False)
+    fnetdata = Fnetdata(atoms=catoms, globaltargets=targets)
     fnetdata.atomicweights = batomicweights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -446,8 +444,8 @@ def test_sgeometries_extfeatures(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: No
-        atomic targets: /
+        global targets: No
+        atomic targets: No
         external features: Yes
         manual dataset weights: No
         manual gradient weights: No
@@ -472,7 +470,7 @@ def test_sgeometries_atomictargets(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: No
         manual dataset weights: No
@@ -484,7 +482,7 @@ def test_sgeometries_atomictargets(tmpdir):
     satoms = get_bulk_geometries()
     targets = get_properties_byatoms(satoms, 3, True)
 
-    fnetdata = Fnetdata(atoms=satoms, targets=targets, atomic=True)
+    fnetdata = Fnetdata(atoms=satoms, atomictargets=targets)
     fnetdata.dump(os.path.join(tmpdir, fname))
 
     hdf5 = Hdf5(os.path.join(tmpdir, fname))
@@ -498,7 +496,7 @@ def test_sgeometries_atomictargets_extfeatures(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: Yes
         manual dataset weights: No
@@ -511,8 +509,7 @@ def test_sgeometries_atomictargets_extfeatures(tmpdir):
     targets = get_properties_byatoms(satoms, 3, True)
     features = get_properties_byatoms(satoms, 13, True)
 
-    fnetdata = Fnetdata(atoms=satoms, features=features, targets=targets,
-                        atomic=True)
+    fnetdata = Fnetdata(atoms=satoms, features=features, atomictargets=targets)
     fnetdata.dump(os.path.join(tmpdir, fname))
 
     hdf5 = Hdf5(os.path.join(tmpdir, fname))
@@ -526,7 +523,7 @@ def test_sgeometries_atomictargets_weights(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: No
         manual dataset weights: Yes
@@ -541,7 +538,7 @@ def test_sgeometries_atomictargets_weights(tmpdir):
     weights = np.random.randint(1, 100, len(satoms), dtype=int)
     targets = get_properties_byatoms(satoms, 3, True)
 
-    fnetdata = Fnetdata(atoms=satoms, targets=targets, atomic=True)
+    fnetdata = Fnetdata(atoms=satoms, atomictargets=targets)
     fnetdata.weights = weights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -556,7 +553,7 @@ def test_sgeometries_atomictargets_atomicweights(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: No
         manual dataset weights: No
@@ -569,7 +566,7 @@ def test_sgeometries_atomictargets_atomicweights(tmpdir):
     atomicweights = get_atomicweights_byatoms(satoms)
     targets = get_properties_byatoms(satoms, 3, True)
 
-    fnetdata = Fnetdata(atoms=satoms, targets=targets, atomic=True)
+    fnetdata = Fnetdata(atoms=satoms, atomictargets=targets)
     fnetdata.atomicweights = atomicweights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -584,7 +581,7 @@ def test_sgeometries_atomictargets_batomicweights(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: No
         atomic targets: Yes
         external features: No
         manual dataset weights: No
@@ -597,7 +594,7 @@ def test_sgeometries_atomictargets_batomicweights(tmpdir):
     batomicweights = get_batomicweights_byatoms(satoms)
     targets = get_properties_byatoms(satoms, 3, True)
 
-    fnetdata = Fnetdata(atoms=satoms, targets=targets, atomic=True)
+    fnetdata = Fnetdata(atoms=satoms, atomictargets=targets)
     fnetdata.atomicweights = batomicweights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -612,7 +609,7 @@ def test_sgeometries_globaltargets(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: No
         manual dataset weights: No
@@ -624,7 +621,7 @@ def test_sgeometries_globaltargets(tmpdir):
     satoms = get_bulk_geometries()
     targets = get_properties_byatoms(satoms, 3, False)
 
-    fnetdata = Fnetdata(atoms=satoms, targets=targets, atomic=False)
+    fnetdata = Fnetdata(atoms=satoms, globaltargets=targets)
     fnetdata.dump(os.path.join(tmpdir, fname))
 
     hdf5 = Hdf5(os.path.join(tmpdir, fname))
@@ -638,7 +635,7 @@ def test_sgeometries_globaltargets_extfeatures(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: Yes
         manual dataset weights: No
@@ -651,8 +648,7 @@ def test_sgeometries_globaltargets_extfeatures(tmpdir):
     targets = get_properties_byatoms(satoms, 3, False)
     features = get_properties_byatoms(satoms, 13, True)
 
-    fnetdata = Fnetdata(atoms=satoms, features=features, targets=targets,
-                        atomic=False)
+    fnetdata = Fnetdata(atoms=satoms, features=features, globaltargets=targets)
     fnetdata.dump(os.path.join(tmpdir, fname))
 
     hdf5 = Hdf5(os.path.join(tmpdir, fname))
@@ -666,7 +662,7 @@ def test_sgeometries_globaltargets_weights(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: No
         manual dataset weights: Yes
@@ -681,7 +677,7 @@ def test_sgeometries_globaltargets_weights(tmpdir):
     weights = np.random.randint(1, 100, len(satoms), dtype=int)
     targets = get_properties_byatoms(satoms, 3, False)
 
-    fnetdata = Fnetdata(atoms=satoms, targets=targets, atomic=False)
+    fnetdata = Fnetdata(atoms=satoms, globaltargets=targets)
     fnetdata.weights = weights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -696,7 +692,7 @@ def test_sgeometries_globaltargets_atomicweights(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: No
         manual dataset weights: No
@@ -709,7 +705,7 @@ def test_sgeometries_globaltargets_atomicweights(tmpdir):
     atomicweights = get_atomicweights_byatoms(satoms)
     targets = get_properties_byatoms(satoms, 3, False)
 
-    fnetdata = Fnetdata(atoms=satoms, targets=targets, atomic=False)
+    fnetdata = Fnetdata(atoms=satoms, globaltargets=targets)
     fnetdata.atomicweights = atomicweights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
@@ -724,7 +720,7 @@ def test_sgeometries_globaltargets_batomicweights(tmpdir):
 
         structures: Yes
         periodic: Yes
-        targets: Yes
+        global targets: Yes
         atomic targets: No
         external features: No
         manual dataset weights: No
@@ -737,7 +733,310 @@ def test_sgeometries_globaltargets_batomicweights(tmpdir):
     batomicweights = get_batomicweights_byatoms(satoms)
     targets = get_properties_byatoms(satoms, 3, False)
 
-    fnetdata = Fnetdata(atoms=satoms, targets=targets, atomic=False)
+    fnetdata = Fnetdata(atoms=satoms, globaltargets=targets)
+    fnetdata.atomicweights = batomicweights
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+#######################################################################
+
+
+def test_cgeometries_globaltargets_atomictargets(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: No
+        global targets: Yes
+        atomic targets: Yes
+        external features: No
+        manual dataset weights: No
+        manual gradient weights: No
+
+    '''
+
+    fname = 'cgeometries_globaltargets_atomictargets.hdf5'
+    catoms = get_cluster_geometries()
+    globaltargets = get_properties_byatoms(catoms, 3, False)
+    atomictargets = get_properties_byatoms(catoms, 3, True)
+
+    fnetdata = Fnetdata(atoms=catoms, globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_cgeometries_globaltargets_atomictargets_extfeatures(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: No
+        global targets: Yes
+        atomic targets: Yes
+        external features: Yes
+        manual dataset weights: No
+        manual gradient weights: No
+
+    '''
+
+    fname = 'cgeometries_globaltargets_atomictargets_extfeatures.hdf5'
+    catoms = get_cluster_geometries()
+    globaltargets = get_properties_byatoms(catoms, 3, False)
+    atomictargets = get_properties_byatoms(catoms, 3, True)
+    features = get_properties_byatoms(catoms, 13, True)
+
+    fnetdata = Fnetdata(atoms=catoms, features=features,
+                        globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_cgeometries_globaltargets_atomictargets_weights(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: No
+        global targets: Yes
+        atomic targets: Yes
+        external features: No
+        manual dataset weights: Yes
+        manual gradient weights: No
+
+    '''
+
+    fname = 'cgeometries_globaltargets_atomictargets_weights.hdf5'
+    catoms = get_cluster_geometries()
+    # fix random seed for reproduction purposes
+    np.random.seed(42)
+    weights = np.random.randint(1, 100, len(catoms), dtype=int)
+    globaltargets = get_properties_byatoms(catoms, 3, False)
+    atomictargets = get_properties_byatoms(catoms, 3, True)
+
+    fnetdata = Fnetdata(atoms=catoms, globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.weights = weights
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_cgeometries_globaltargets_atomictargets_atomicweights(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: No
+        global targets: Yes
+        atomic targets: Yes
+        external features: No
+        manual dataset weights: No
+        manual gradient weights: Yes
+
+    '''
+
+    fname = 'cgeometries_globaltargets_atomictargets_atomicweights.hdf5'
+    catoms = get_cluster_geometries()
+    atomicweights = get_atomicweights_byatoms(catoms)
+    globaltargets = get_properties_byatoms(catoms, 3, False)
+    atomictargets = get_properties_byatoms(catoms, 3, True)
+
+    fnetdata = Fnetdata(atoms=catoms, globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.atomicweights = atomicweights
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_cgeometries_globaltargets_atomictargets_batomicweights(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: No
+        global targets: Yes
+        atomic targets: Yes
+        external features: No
+        manual dataset weights: No
+        manual gradient weights: Yes
+
+    '''
+
+    fname = 'cgeometries_globaltargets_atomictargets_batomicweights.hdf5'
+    catoms = get_cluster_geometries()
+    batomicweights = get_batomicweights_byatoms(catoms)
+    globaltargets = get_properties_byatoms(catoms, 3, False)
+    atomictargets = get_properties_byatoms(catoms, 3, True)
+
+    fnetdata = Fnetdata(atoms=catoms, globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.atomicweights = batomicweights
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_sgeometries_globaltargets_atomictargets(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: Yes
+        global targets: Yes
+        atomic targets: Yes
+        external features: No
+        manual dataset weights: No
+        manual gradient weights: No
+
+    '''
+
+    fname = 'sgeometries_globaltargets_atomictargets.hdf5'
+    satoms = get_bulk_geometries()
+    globaltargets = get_properties_byatoms(satoms, 3, False)
+    atomictargets = get_properties_byatoms(satoms, 3, True)
+
+    fnetdata = Fnetdata(atoms=satoms, globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_sgeometries_globaltargets_atomictargets_extfeatures(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: Yes
+        global targets: Yes
+        atomic targets: Yes
+        external features: Yes
+        manual dataset weights: No
+        manual gradient weights: No
+
+    '''
+
+    fname = 'sgeometries_globaltargets_atomictargets_extfeatures.hdf5'
+    satoms = get_bulk_geometries()
+    globaltargets = get_properties_byatoms(satoms, 3, False)
+    atomictargets = get_properties_byatoms(satoms, 3, True)
+    features = get_properties_byatoms(satoms, 13, True)
+
+    fnetdata = Fnetdata(atoms=satoms, features=features,
+                        globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_sgeometries_globaltargets_atomictargets_weights(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: Yes
+        global targets: Yes
+        atomic targets: Yes
+        external features: No
+        manual dataset weights: Yes
+        manual gradient weights: No
+
+    '''
+
+    fname = 'sgeometries_globaltargets_atomictargets_weights.hdf5'
+    satoms = get_bulk_geometries()
+    # fix random seed for reproduction purposes
+    np.random.seed(42)
+    weights = np.random.randint(1, 100, len(satoms), dtype=int)
+    globaltargets = get_properties_byatoms(satoms, 3, False)
+    atomictargets = get_properties_byatoms(satoms, 3, True)
+
+    fnetdata = Fnetdata(atoms=satoms, globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.weights = weights
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_sgeometries_globaltargets_atomictargets_atomicweights(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: Yes
+        global targets: Yes
+        atomic targets: Yes
+        external features: No
+        manual dataset weights: No
+        manual gradient weights: Yes
+
+    '''
+
+    fname = 'sgeometries_globaltargets_atomictargets_atomicweights.hdf5'
+    satoms = get_bulk_geometries()
+    atomicweights = get_atomicweights_byatoms(satoms)
+    globaltargets = get_properties_byatoms(satoms, 3, False)
+    atomictargets = get_properties_byatoms(satoms, 3, True)
+
+    fnetdata = Fnetdata(atoms=satoms, globaltargets=globaltargets,
+                        atomictargets=atomictargets)
+    fnetdata.atomicweights = atomicweights
+    fnetdata.dump(os.path.join(tmpdir, fname))
+
+    hdf5 = Hdf5(os.path.join(tmpdir, fname))
+    equal = hdf5.equals(os.path.join(REFPATH, '_' + fname))
+
+    assert equal, 'h5diff reports mismatch in generated datasets.'
+
+
+def test_sgeometries_globaltargets_atomictargets_batomicweights(tmpdir):
+    '''Test dataset generation for configuration:
+
+        structures: Yes
+        periodic: Yes
+        global targets: Yes
+        atomic targets: Yes
+        external features: No
+        manual dataset weights: No
+        manual gradient weights: Yes
+
+    '''
+
+    fname = 'sgeometries_globaltargets_atomictargets_batomicweights.hdf5'
+    satoms = get_bulk_geometries()
+    batomicweights = get_batomicweights_byatoms(satoms)
+    globaltargets = get_properties_byatoms(satoms, 3, False)
+    atomictargets = get_properties_byatoms(satoms, 3, True)
+
+    fnetdata = Fnetdata(atoms=satoms, globaltargets=globaltargets,
+                        atomictargets=atomictargets)
     fnetdata.atomicweights = batomicweights
     fnetdata.dump(os.path.join(tmpdir, fname))
 
